@@ -135,6 +135,19 @@ class VerticaDialect(PGDialect):
         return [row[0] for row in rs if not row[0].startswith('v_')]
 
 
+    @reflection.cache
+    def get_table_comment(self, connection, table_name, schema=None, **kw):
+        schema_conditional = (
+            "" if schema is None else "AND object_schema = '{schema}'".format(schema=schema))
+        query = """
+        SELECT comment FROM v_catalog.comments WHERE object_type = 'TABLE'
+        AND object_name = '{table_name}'
+        {schema_conditional}
+        """.format(table_name=table_name, schema_conditional=schema_conditional)
+        rs = connection.execute(query)
+        return {"text": rs.scalar()}
+
+
     @reflection.cache
     def get_table_names(self, connection, schema=None, **kw):
         s = ["SELECT table_name FROM v_catalog.tables"]
